==> haskell-tasty-golden-2.3.5-187-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-golden
version:              2.3.5
visibility:           public
id:                   tasty-golden-2.3.5-644Ig7bMVTbUC3kn7y7XN
key:                  tasty-golden-2.3.5-644Ig7bMVTbUC3kn7y7XN
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka
homepage:             https://github.com/UnkindPartition/tasty-golden
synopsis:             Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.

category:             Testing
abi:                  f1a59997f4561129a655af1125638d63
exposed:              True
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage

hidden-modules:       Test.Tasty.Golden.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-golden-2.3.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-golden-2.3.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-golden-2.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-golden
hs-libraries:         HStasty-golden-2.3.5-644Ig7bMVTbUC3kn7y7XN
depends:
    async-2.2.5-IoLsQL5aW4y4qbn8NJyPCy base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    optparse-applicative-0.18.1.0-GDwWCLBUeEeIARGaJHYM6i
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C tasty-1.5-nBq4EpoIA9DEhHe7l1juL
    temporary-1.3-6v3kkobkoyrEdh9PtoqgTt text-2.0.2
    typed-process-0.2.13.0-4ehRsQ9jjfB1VUQgi4WQQC

haddock-interfaces:
    /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock

haddock-html:         /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-golden-2.3.5-188-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-golden
version:              2.3.5
visibility:           public
id:                   tasty-golden-2.3.5-7mqWuSHc1xI6kq8auWCt2l
key:                  tasty-golden-2.3.5-7mqWuSHc1xI6kq8auWCt2l
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka
homepage:             https://github.com/UnkindPartition/tasty-golden
synopsis:             Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.

category:             Testing
abi:                  f15cbc4767feba3ecc7efbaa4a6c8da2
exposed:              True
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage

hidden-modules:       Test.Tasty.Golden.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-golden-2.3.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-golden-2.3.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-golden-2.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-golden
hs-libraries:         HStasty-golden-2.3.5-7mqWuSHc1xI6kq8auWCt2l
depends:
    async-2.2.5-G01HdI4hTJCBY7T6N2YLEE base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    optparse-applicative-0.18.1.0-9tmiQ8Ij14j6zIjbjXGWFB
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5-44yHwxT3geWAErkmGuwy0z
    temporary-1.3-BYzoIbeonbyAEdWaOuGJ1M text-2.0.2
    typed-process-0.2.13.0-2BRBFpLXpuY9PKTSPRkyKk

haddock-interfaces:
    /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock

haddock-html:         /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
